@@ -58,13 +58,7 @@ from .adn import (
     ADNSeasonIE,
 )
 from .adobeconnect import AdobeConnectIE
-from .adobetv import (
-    AdobeTVChannelIE,
-    AdobeTVEmbedIE,
-    AdobeTVIE,
-    AdobeTVShowIE,
-    AdobeTVVideoIE,
-)
+from .adobetv import AdobeTVVideoIE
 from .adultswim import AdultSwimIE
 from .aenetworks import (
     AENetworksCollectionIE,
@@ -152,7 +146,6 @@ from .ard import (
     ARDBetaMediathekIE,
     ARDMediathekCollectionIE,
 )
-from .arkena import ArkenaIE
 from .arnes import ArnesIE
 from .art19 import (
     Art19IE,
@@ -405,16 +398,12 @@ from .cloudflarestream import CloudflareStreamIE
 from .cloudycdn import CloudyCDNIE
 from .clubic import ClubicIE
 from .clyp import ClypIE
-from .cmt import CMTIE
 from .cnbc import CNBCVideoIE
 from .cnn import (
     CNNIE,
     CNNIndonesiaIE,
 )
-from .comedycentral import (
-    ComedyCentralIE,
-    ComedyCentralTVIE,
-)
+from .comedycentral import ComedyCentralIE
 from .commonmistakes import (
     BlobIE,
     CommonMistakesIE,
@@ -435,7 +424,6 @@ from .cpac import (
     CPACPlaylistIE,
 )
 from .cracked import CrackedIE
-from .crackle import CrackleIE
 from .craftsy import CraftsyIE
 from .crooksandliars import CrooksAndLiarsIE
 from .crowdbunker import (
@@ -455,10 +443,6 @@ from .curiositystream import (
     CuriosityStreamIE,
     CuriosityStreamSeriesIE,
 )
-from .cwtv import (
-    CWTVIE,
-    CWTVMovieIE,
-)
 from .cybrary import (
     CybraryCourseIE,
     CybraryIE,
@@ -636,7 +620,10 @@ from .fancode import (
     FancodeVodIE,
 )
 from .fathom import FathomIE
-from .faulio import FaulioLiveIE
+from .faulio import (
+    FaulioIE,
+    FaulioLiveIE,
+)
 from .faz import FazIE
 from .fc2 import (
     FC2IE,
@@ -1149,7 +1136,6 @@ from .mit import (
     OCWMITIE,
     TechTVMITIE,
 )
-from .mitele import MiTeleIE
 from .mixch import (
     MixchArchiveIE,
     MixchIE,
@@ -1187,15 +1173,7 @@ from .moview import MoviewPlayIE
 from .moviezine import MoviezineIE
 from .movingimage import MovingImageIE
 from .msn import MSNIE
-from .mtv import (
-    MTVDEIE,
-    MTVIE,
-    MTVItaliaIE,
-    MTVItaliaProgrammaIE,
-    MTVJapanIE,
-    MTVServicesEmbeddedIE,
-    MTVVideoIE,
-)
+from .mtv import MTVIE
 from .muenchentv import MuenchenTVIE
 from .murrtube import (
     MurrtubeIE,
@@ -1337,12 +1315,7 @@ from .nhk import (
     NhkVodProgramIE,
 )
 from .nhl import NHLIE
-from .nick import (
-    NickBrIE,
-    NickDeIE,
-    NickIE,
-    NickRuIE,
-)
+from .nick import NickIE
 from .niconico import (
     NiconicoHistoryIE,
     NiconicoIE,
@@ -1454,6 +1427,7 @@ from .onet import (
     OnetPlIE,
 )
 from .onionstudios import OnionStudiosIE
+from .onsen import OnsenIE
 from .opencast import (
     OpencastIE,
     OpencastPlaylistIE,
@@ -1487,10 +1461,6 @@ from .panopto import (
     PanoptoListIE,
     PanoptoPlaylistIE,
 )
-from .paramountplus import (
-    ParamountPlusIE,
-    ParamountPlusSeriesIE,
-)
 from .parler import ParlerIE
 from .parlview import ParlviewIE
 from .parti import (
@@ -1544,11 +1514,6 @@ from .piramidetv import (
     PiramideTVChannelIE,
     PiramideTVIE,
 )
-from .pixivsketch import (
-    PixivSketchIE,
-    PixivSketchUserIE,
-)
-from .pladform import PladformIE
 from .planetmarathi import PlanetMarathiIE
 from .platzi import (
     PlatziCourseIE,
@@ -1805,7 +1770,6 @@ from .rutube import (
     RutubePlaylistIE,
     RutubeTagsIE,
 )
-from .rutv import RUTVIE
 from .ruutu import RuutuIE
 from .ruv import (
     RuvIE,
@@ -1875,7 +1839,6 @@ from .simplecast import (
     SimplecastPodcastIE,
 )
 from .sina import SinaIE
-from .sixplay import SixPlayIE
 from .skeb import SkebIE
 from .sky import (
     SkyNewsIE,
@@ -1903,7 +1866,12 @@ from .skynewsau import SkyNewsAUIE
 from .slideshare import SlideshareIE
 from .slideslive import SlidesLiveIE
 from .slutload import SlutloadIE
-from .smotrim import SmotrimIE
+from .smotrim import (
+    SmotrimAudioIE,
+    SmotrimIE,
+    SmotrimLiveIE,
+    SmotrimPlaylistIE,
+)
 from .snapchat import SnapchatSpotlightIE
 from .snotr import SnotrIE
 from .softwhiteunderbelly import SoftWhiteUnderbellyIE
@@ -1931,12 +1899,13 @@ from .soundgasm import (
     SoundgasmProfileIE,
 )
 from .southpark import (
+    SouthParkComBrIE,
+    SouthParkCoUkIE,
     SouthParkDeIE,
     SouthParkDkIE,
     SouthParkEsIE,
     SouthParkIE,
     SouthParkLatIE,
-    SouthParkNlIE,
 )
 from .sovietscloset import (
     SovietsClosetIE,
@@ -1947,17 +1916,9 @@ from .spankbang import (
     SpankBangPlaylistIE,
 )
 from .spiegel import SpiegelIE
-from .spike import (
-    BellatorIE,
-    ParamountNetworkIE,
-)
 from .sport5 import Sport5IE
 from .sportbox import SportBoxIE
 from .sportdeutschland import SportDeutschlandIE
-from .spotify import (
-    SpotifyIE,
-    SpotifyShowIE,
-)
 from .spreaker import (
     SpreakerIE,
     SpreakerShowIE,
@@ -1984,6 +1945,7 @@ from .startrek import StarTrekIE
 from .startv import StarTVIE
 from .steam import (
     SteamCommunityBroadcastIE,
+    SteamCommunityIE,
     SteamIE,
 )
 from .stitcher import (
@@ -2177,6 +2139,7 @@ from .tubitv import (
 )
 from .tumblr import TumblrIE
 from .tunein import (
+    TuneInEmbedIE,
     TuneInPodcastEpisodeIE,
     TuneInPodcastIE,
     TuneInShortenerIE,
@@ -2215,7 +2178,6 @@ from .tvc import (
 from .tver import TVerIE
 from .tvigle import TvigleIE
 from .tviplayer import TVIPlayerIE
-from .tvland import TVLandIE
 from .tvn24 import TVN24IE
 from .tvnoe import TVNoeIE
 from .tvopengr import (
@@ -2312,7 +2274,6 @@ from .utreon import UtreonIE
 from .varzesh3 import Varzesh3IE
 from .vbox7 import Vbox7IE
 from .veo import VeoIE
-from .vesti import VestiIE
 from .vevo import (
     VevoIE,
     VevoPlaylistIE,
@@ -2501,7 +2462,6 @@ from .wykop import (
     WykopPostCommentIE,
     WykopPostIE,
 )
-from .xanimu import XanimuIE
 from .xboxclips import XboxClipsIE
 from .xhamster import (
     XHamsterEmbedIE,
