@@ -26,37 +26,13 @@ class ToggleIE(InfoExtractor):
         },
         'params': {
             'skip_download': 'm3u8 download',
-        }
+        },
     }, {
-        'note': 'DRM-protected video',
         'url': 'http://www.mewatch.sg/en/movies/dug-s-special-mission/341413',
-        'info_dict': {
-            'id': '341413',
-            'ext': 'wvm',
-            'title': 'Dug\'s Special Mission',
-            'description': 'md5:e86c6f4458214905c1772398fabc93e0',
-            'upload_date': '20150827',
-            'timestamp': 1440644006,
-        },
-        'params': {
-            'skip_download': 'DRM-protected wvm download',
-        }
+        'only_matching': True,
     }, {
-        # this also tests correct video id extraction
-        'note': 'm3u8 links are geo-restricted, but Android/mp4 is okay',
         'url': 'http://www.mewatch.sg/en/series/28th-sea-games-5-show/28th-sea-games-5-show-ep11/332861',
-        'info_dict': {
-            'id': '332861',
-            'ext': 'mp4',
-            'title': '28th SEA Games (5 Show) -  Episode  11',
-            'description': 'md5:3cd4f5f56c7c3b1340c50a863f896faa',
-            'upload_date': '20150605',
-            'timestamp': 1433480166,
-        },
-        'params': {
-            'skip_download': 'DRM-protected wvm download',
-        },
-        'skip': 'm3u8 links are geo-restricted'
+        'only_matching': True,
     }, {
         'url': 'http://video.toggle.sg/en/clips/seraph-sun-aloysius-will-suddenly-sing-some-old-songs-in-high-pitch-on-set/343331',
         'only_matching': True,
@@ -92,14 +68,14 @@ class ToggleIE(InfoExtractor):
                     'LocaleLanguage': '',
                     'LocaleCountry': '',
                     'LocaleDevice': '',
-                    'LocaleUserState': 0
+                    'LocaleUserState': 0,
                 },
                 'Platform': 0,
                 'SiteGuid': 0,
                 'DomainID': '0',
                 'UDID': '',
                 'ApiUser': self._API_USER,
-                'ApiPass': self._API_PASS
+                'ApiPass': self._API_PASS,
             },
             'MediaID': video_id,
             'mediaType': 0,
@@ -107,7 +83,7 @@ class ToggleIE(InfoExtractor):
 
         info = self._download_json(
             'http://tvpapi.as.tvinci.com/v2_9/gateways/jsonpostgw.aspx?m=GetMediaInfo',
-            video_id, 'Downloading video info json', data=json.dumps(params).encode('utf-8'))
+            video_id, 'Downloading video info json', data=json.dumps(params).encode())
 
         title = info['MediaName']
 
@@ -122,8 +98,8 @@ class ToggleIE(InfoExtractor):
             if ext == 'm3u8':
                 m3u8_formats = self._extract_m3u8_formats(
                     video_url, video_id, ext='mp4', m3u8_id=vid_format,
-                    note='Downloading %s m3u8 information' % vid_format,
-                    errnote='Failed to download %s m3u8 information' % vid_format,
+                    note=f'Downloading {vid_format} m3u8 information',
+                    errnote=f'Failed to download {vid_format} m3u8 information',
                     fatal=False)
                 for f in m3u8_formats:
                     # Apple FairPlay Streaming
@@ -133,14 +109,14 @@ class ToggleIE(InfoExtractor):
             elif ext == 'mpd':
                 formats.extend(self._extract_mpd_formats(
                     video_url, video_id, mpd_id=vid_format,
-                    note='Downloading %s MPD manifest' % vid_format,
-                    errnote='Failed to download %s MPD manifest' % vid_format,
+                    note=f'Downloading {vid_format} MPD manifest',
+                    errnote=f'Failed to download {vid_format} MPD manifest',
                     fatal=False))
             elif ext == 'ism':
                 formats.extend(self._extract_ism_formats(
                     video_url, video_id, ism_id=vid_format,
-                    note='Downloading %s ISM manifest' % vid_format,
-                    errnote='Failed to download %s ISM manifest' % vid_format,
+                    note=f'Downloading {vid_format} ISM manifest',
+                    errnote=f'Failed to download {vid_format} ISM manifest',
                     fatal=False))
             elif ext == 'mp4':
                 formats.append({
@@ -154,7 +130,6 @@ class ToggleIE(InfoExtractor):
                         and meta.get('Key') == 'Encryption' and meta.get('Value') == '1'):
                     self.report_drm(video_id)
             # Most likely because geo-blocked if no formats and no DRM
-        self._sort_formats(formats)
 
         thumbnails = []
         for picture in info.get('Pictures', []):
